# SPDX-License-Identifier: GPL-3.0-only
# (C) Copyright CERN 2021. All rights not expressly granted are reserved.

from availsim4core.src.simulation.simulation import Simulation


class QuickParse(Simulation):

    def __init__(self):
        """
        TBD
        """
        pass
